@@ -1,49 +1,49 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 """Splunk Application abstraction module"""
 
-# Python Standard Libraries
 import hashlib
+import inspect
 import logging
 import os
+import platform
 import re
+import shutil
 import stat
-import inspect
 import tarfile
 import tempfile
-import shutil
-
 from io import BytesIO
-import platform
 
-# Custom Libraries
-from splunk_appinspect.python_modules_metadata import python_modules_metadata_store
 from splunk_appinspect.configuration_parser import InvalidSectionError
-from . import alert_actions
-from . import app_configuration_file
-from . import app_package_handler
-from . import authentication_configuration_file
-from . import authorize_configuration_file
-from . import custom_commands
-from . import custom_visualizations
-from . import configuration_file
-from . import configuration_parser
-from . import distsearch_configuration_file
-from . import file_resource
-from . import indexes_configuration_file
-from . import inputs_configuration_file
-from . import inputs_specification_file
-from . import inspected_file
-from . import modular_inputs
-from . import outputs_configuration_file
-from . import props_configuration_file
-from . import rest_map
-from . import saved_searches
-from . import transforms_configuration_file
-from . import web_configuration_file
-from . import workflow_actions
-from . import python_analyzer
-from . import telemetry_configuration_file
-from . import collections_configuration_file
+from splunk_appinspect.python_modules_metadata import python_modules_metadata_store
+
+from . import (
+    alert_actions,
+    app_configuration_file,
+    app_package_handler,
+    authentication_configuration_file,
+    authorize_configuration_file,
+    collections_configuration_file,
+    configuration_file,
+    configuration_parser,
+    custom_commands,
+    custom_visualizations,
+    distsearch_configuration_file,
+    file_resource,
+    indexes_configuration_file,
+    inputs_configuration_file,
+    inputs_specification_file,
+    inspected_file,
+    modular_inputs,
+    outputs_configuration_file,
+    props_configuration_file,
+    python_analyzer,
+    rest_map,
+    saved_searches,
+    telemetry_configuration_file,
+    transforms_configuration_file,
+    web_configuration_file,
+    workflow_actions,
+)
 
 # Third Party Libraries
 if not platform.system() == "Windows":
@@ -293,13 +293,14 @@ class App(object):
         if conf_file_key in self.invalid_conf_files:
             raise self.invalid_conf_files[conf_file_key]
         if not self.app_conf_files.get(conf_file_key):
+            getconfig = "get_config"
             log_output = (
-                "'{}' called '{}' to retrieve the configuration file '{}'"
-                " at directory '{}'. App filepath: {}"
-            ).format(__file__, "get_config", name, dir, app_filepath)
+                f"'{__file__}' called '{getconfig}' to retrieve the configuration file '{name}'"
+                f" at directory '{dir}'. App filepath: {app_filepath}"
+            )
             logger.debug(log_output)
             if not self.file_exists(app_filepath):
-                error_output = "No such conf file: {}".format(app_filepath)
+                error_output = f"No such conf file: {app_filepath}"
                 raise IOError(error_output)
 
             # Makes generic configuration file if no specified configuration file is
@@ -329,13 +330,14 @@ class App(object):
         """
         app_filepath = self.get_filename(dir, name)
 
+        get_config = "get_config"
         log_output = (
-            "'{}' called '{}' to retrieve the configuration file '{}'"
-            " at directory '{}'. App filepath: {}"
-        ).format(__file__, "get_config", name, dir, app_filepath)
+            f"'{__file__}' called '{get_config}' to retrieve the configuration file '{name}'"
+            f" at directory '{dir}'. App filepath: {app_filepath}"
+        )
         logger.debug(log_output)
         if not self.file_exists(app_filepath):
-            error_output = ("No such conf file: {}").format(app_filepath)
+            error_output = f"No such conf file: {app_filepath}"
             raise IOError(error_output)
 
         # Makes generic configuration file if no specified configuration file is
@@ -346,7 +348,9 @@ class App(object):
         with open(app_filepath, "rb") as file:
             try:
                 config_file = configuration_parser.parse(
-                    file, config_file, configuration_parser.specification_lexer,
+                    file,
+                    config_file,
+                    configuration_parser.specification_lexer,
                 )
             except InvalidSectionError as e:
                 # re-raise the error from parser
@@ -368,13 +372,14 @@ class App(object):
         # TODO: investigate if meta file class should exist
         app_filepath = self.get_filename(directory, name)
 
+        get_config = "get_config"
         log_output = (
-            "'{}' called '{}' to retrieve the configuration file '{}'"
-            " at directory '{}'. App filepath: {}"
-        ).format(__file__, "get_config", name, directory, app_filepath)
+            f"'{__file__}' called '{get_config}' to retrieve the configuration file '{name}'"
+            f" at directory '{directory}'. App filepath: {app_filepath}"
+        )
         logger.debug(log_output)
         if not self.file_exists(app_filepath):
-            error_output = ("No such metadata file: {}").format(app_filepath)
+            error_output = f"No such metadata file: {app_filepath}"
             raise IOError(error_output)
 
         # Makes generic meta file if no specified meta file is
@@ -402,10 +407,11 @@ class App(object):
         conf_content = fh.read()
         fh.close()
 
+        raw_conf = "get_raw_conf"
         log_output = (
-            "'{}' called '{}' to retrieve the configuration file '{}'"
-            " at directory '{}'. App filepath: {}"
-        ).format(__file__, "get_raw_conf", name, dir, app_filepath)
+            f"'{__file__}' called '{raw_conf}' to retrieve the configuration file '{name}'"
+            f" at directory '{dir}'. App filepath: {app_filepath}"
+        )
         logger.debug(log_output)
 
         return conf_content
@@ -435,36 +441,41 @@ class App(object):
             logger_error_message = (
                 "An error occurred trying to retrieve"
                 " information from the app.conf file."
-                " Error: {}"
-                " Stanza: {}"
-                " Property: {}"
+                " Error: {error}"
+                " Stanza: {santa}"
+                " Property: {property}"
             )
 
             property_to_return = app_config.get(stanza, option)
         except IOError as exception:
             error_message = repr(exception)
-            logger_output = ("The `app.conf` file does not exist." " Error: {}").format(
-                error_message
+            logger_output = (
+                f"The `app.conf` file does not exist." f" Error: {error_message}"
             )
             logger.error(logger_output)
-            property_to_return = "[MISSING `{}/app.conf`]".format(app_conf_dir)
+            property_to_return = f"[MISSING `{app_conf_dir}/app.conf`]"
             raise exception
         except configuration_file.NoSectionError as exception:
             error_message = repr(exception)
-            logger_output = logger_error_message.format(error_message, stanza, option)
+            logger_output = logger_error_message.format(
+                error=error_message, santa=stanza, property=option
+            )
             logger.error(logger_output)
-            property_to_return = ("[MISSING `{}/app.conf` stanza `{}`]").format(
-                app_conf_dir, stanza
+            property_to_return = (
+                f"[MISSING `{app_conf_dir}/app.conf` stanza `{stanza}`]"
             )
             raise exception
         except configuration_file.NoOptionError as exception:
             # TODO: tests needed
             error_message = repr(exception)
-            logger_output = logger_error_message.format(error_message, stanza, option)
+            logger_output = logger_error_message.format(
+                error=error_message, santa=stanza, property=option
+            )
             logger.error(logger_output)
             property_to_return = (
-                "[MISSING `{}/app.conf` stanza [{}]" " property `{}`]"
-            ).format(app_conf_dir, stanza, option)
+                f"[MISSING `{app_conf_dir}/app.conf` stanza [{stanza}]"
+                " property `{option}`]"
+            )
             raise exception
         except Exception as exception:
             # TODO: tests needed
@@ -472,8 +483,8 @@ class App(object):
             logger_output = (
                 "An unexpected error occurred while trying to"
                 " retrieve information from the app.conf file"
-                " Error: {}"
-            ).format(error_message)
+                f" Error: {error_message}"
+            )
             logger.error(logger_output)
             property_to_return = "[Unexpected error occurred]"
             raise exception
@@ -500,6 +511,7 @@ class App(object):
         app_info["name"] = self.name
         app_info["hash"] = self._get_hash()
         app_info["label"] = self.label
+        app_info["package_id"] = self.package_id
 
         return app_info
 
@@ -546,6 +558,20 @@ class App(object):
 
         return self._get_app_info("ui", "label")
 
+    @property
+    def package_id(self):
+        """Helper function to retrieve the app.conf [package] stanza's `id`
+        property.
+
+        Returns:
+            String: the default/app.conf [package] stanza's `id` property
+        """
+        if self.file_exists("default", "app.conf") and self.app_conf().has_option(
+            "package", "id"
+        ):
+            return self._get_app_info("package", "id")
+        return None
+
     def _get_hash(self):
         md5 = hashlib.md5()
 
@@ -685,14 +711,16 @@ class App(object):
         file_path = os.path.join(self.app_dir, *path_parts)
         does_file_exist = os.path.isfile(file_path)
 
+        file_exist = "file_exists"
         log_output = (
-            "'{}.{}' was called. File path being checked:'{}'." " Does File Exist:{}"
-        ).format(__file__, "file_exists", file_path, does_file_exist)
+            f"'{__file__}.{file_exist}' was called. File path being checked:'{file_path}'. "
+            f"Does File Exist: {does_file_exist}"
+        )
         logger.debug(log_output)
         return does_file_exist
 
     def get_config_file_paths(self, config_file_name):
-        """ Return a dict of existing config_file in given name and corresponding folder names
+        """Return a dict of existing config_file in given name and corresponding folder names
         :param config_file_name: name of configuration file
         :return: config_file_paths: map of folder name and configuration file name
         """
@@ -713,15 +741,16 @@ class App(object):
         directory_path = os.path.join(self.app_dir, *path_parts)
         does_file_exist = os.path.isdir(directory_path)
 
+        directory_exists = "directory_exists"
         log_output = (
-            "'{}.{} was called.'. Directory path being checked:'{}'."
-            " Does Directory Exist:{}"
-        ).format(__file__, "directory_exists", directory_path, does_file_exist)
+            f"'{__file__}.{directory_exists} was called.'. Directory path being checked:'{directory_path}'."
+            f" Does Directory Exist:{does_file_exist}"
+        )
         logger.debug(log_output)
         return does_file_exist
 
     def some_files_exist(self, files):
-        """ Takes an array of relative filenames and returns true if any file
+        """Takes an array of relative filenames and returns true if any file
         listed exists.
         """
         # TODO: tests needed
@@ -731,7 +760,7 @@ class App(object):
         return False
 
     def some_directories_exist(self, directories):
-        """ Takes an array of relative paths and returns true if any file
+        """Takes an array of relative paths and returns true if any file
         listed exists.
         """
         for directory in directories:
@@ -740,7 +769,7 @@ class App(object):
         return False
 
     def all_files_exist(self, files):
-        """ Takes an array of relative filenames and returns true if all
+        """Takes an array of relative filenames and returns true if all
         listed files exist.
         """
         # TODO: tests needed
@@ -750,7 +779,7 @@ class App(object):
         return True
 
     def all_directories_exist(self, directories):
-        """ Takes an array of relative paths and returns true if all listed
+        """Takes an array of relative paths and returns true if all listed
         directories exists.
         """
         # TODO: tests needed
@@ -768,7 +797,7 @@ class App(object):
         excluded_types=None,
         excluded_bases=None,
     ):
-        """ Takes a list of patterns and iterates through all files, running
+        """Takes a list of patterns and iterates through all files, running
         each of the patterns on each line of each of those files.
 
         Returns a list of tuples- the first element is the file (with line
@@ -798,9 +827,7 @@ class App(object):
             matches_with_relative_path = []
             for (fileref_output, file_match) in found_matches:
                 filepath, line_number = fileref_output.rsplit(":", 1)
-                relative_file_ref_output = "{}:{}".format(
-                    relative_filepath, line_number
-                )
+                relative_file_ref_output = f"{relative_filepath}:{line_number}"
                 matches_with_relative_path.append(
                     (relative_file_ref_output, file_match)
                 )
@@ -817,7 +844,7 @@ class App(object):
         excluded_types=None,
         excluded_bases=None,
     ):
-        """ Takes a pattern and iterates over matching files, testing each line.
+        """Takes a pattern and iterates over matching files, testing each line.
         Same as search_for_patterns, but with a single pattern.
         """
         excluded_dirs = excluded_dirs or []
@@ -843,7 +870,7 @@ class App(object):
         excluded_bases=None,
         cross_line=10,
     ):
-        """ Takes a list of patterns and iterates through all files, running
+        """Takes a list of patterns and iterates through all files, running
         each of the patterns on all lines those files.
 
         Returns a list of tuples- the first element is the file (with line
@@ -875,9 +902,7 @@ class App(object):
             matches_with_relative_path = []
             for (fileref_output, file_match) in found_matches:
                 _, line_number = fileref_output.rsplit(":", 1)
-                relative_file_ref_output = "{}:{}".format(
-                    relative_filepath, line_number
-                )
+                relative_file_ref_output = f"{relative_filepath}:{line_number}"
                 matches_with_relative_path.append(
                     (relative_file_ref_output, file_match)
                 )
@@ -895,7 +920,7 @@ class App(object):
         excluded_bases=None,
         cross_line=10,
     ):
-        """ Takes a pattern and iterates over matching files, testing each line.
+        """Takes a pattern and iterates over matching files, testing each line.
         Same as search_for_crossline_patterns, but with a single pattern.
         """
         excluded_dirs = excluded_dirs or []
@@ -913,8 +938,7 @@ class App(object):
         )
 
     def is_executable(self, filename, is_full_path=False):
-        """ Checks to see if any of the executable bits are set on a file
-        """
+        """Checks to see if any of the executable bits are set on a file"""
         # TODO: tests needed
         path = os.path.join(self.app_dir, filename) if not is_full_path else filename
         st = os.stat(path)
@@ -1086,7 +1110,7 @@ class App(object):
             os.path.join(
                 self.app_dir,
                 "default/data/ui/views",
-                "{}.xml".format(custom_setup_xml_name),
+                f"{custom_setup_xml_name}.xml",
             )
         )
 
