@@ -5,13 +5,10 @@
 
 Custom alert actions are defined in an **alert_actions.conf** file located in the **/default** directory of the app. For more, see [Custom alert actions overview](http://docs.splunk.com/Documentation/Splunk/latest/AdvancedDev/ModAlertsIntro) and [alert_actions.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Alertactionsconf).
 """
-
-# Python Standard Library
 import logging
 import os
 import sys
 
-# Custom
 import splunk_appinspect
 
 report_display_order = 20
@@ -50,29 +47,24 @@ def check_alert_icon_exists_for_custom_alerts(app, reporter):
                 else:
                     lineno = alert_action.args["icon_path"][1]
                     reporter_output = (
-                        "The alert_actions.conf [{}] specified"
-                        " the icon_path value of {}, but did not"
-                        " find it. File: {}, Line: {}."
-                    ).format(
-                        alert_action.name,
-                        alert_action.relative_icon_path,
-                        filename,
-                        lineno,
+                        f"The alert_actions.conf [{alert_action.name}] specified"
+                        f" the icon_path value of {alert_action.relative_icon_path}, but did not"
+                        f" find it. File: {filename}, Line: {lineno}."
                     )
                     reporter.fail(reporter_output, filename, lineno)
 
             else:
                 lineno = alert_action.lineno
-                reporter_output = (
-                    "No icon_path was specified for [{}]. " "File: {}, Line: {}."
-                ).format(alert_action.name, filename, lineno)
+                reporter_output = f"No icon_path was specified for [{alert_action.name}]. File: {filename}, Line: {lineno}."
                 reporter.fail(reporter_output, filename, lineno)
     else:
         reporter_output = "No alert_actions.conf was found."
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "alert_actions_conf", "cloud", "manual", "python3_version")
+@splunk_appinspect.tags(
+    "splunk_appinspect", "alert_actions_conf", "cloud", "manual", "python3_version"
+)
 @splunk_appinspect.cert_version(min="1.1.0")
 def check_alert_actions_exe_exist(app, reporter, included_tags, target_splunk_version):
     """Check that each custom alert action has a valid executable. If it does, further check
@@ -88,18 +80,19 @@ def check_alert_actions_exe_exist(app, reporter, included_tags, target_splunk_ve
         for alert in alert_actions.get_alert_actions():
             if alert.alert_execute_cmd_specified():
                 # Highlander: There can be only one...
-                if alert.executable_files[0].exists() and\
-                  target_splunk_version >= "splunk_8_0":
-                    _check_python_version_in_alert_action(alert,
-                                                          alert.executable_files[0],
-                                                          reporter,
-                                                          filename)
+                if (
+                    alert.executable_files[0].exists()
+                    and target_splunk_version >= "splunk_8_0"
+                ):
+                    _check_python_version_in_alert_action(
+                        alert, alert.executable_files[0], reporter, filename
+                    )
                 else:
                     lineno = alert.args["alert.execute.cmd"][1]
                     mess = (
-                        "No alert action executable for {} was found in the "
-                        "bin directory. File: {}, Line: {}."
-                    ).format(alert.alert_execute_cmd, filename, lineno)
+                        f"No alert action executable for {alert.alert_execute_cmd} was found in the "
+                        f"bin directory. File: {filename}, Line: {lineno}."
+                    )
                     reporter.fail(mess, filename, lineno)
             else:
                 win_exes = alert.count_win_exes()
@@ -112,10 +105,9 @@ def check_alert_actions_exe_exist(app, reporter, included_tags, target_splunk_ve
                     # The following logic will only take effect when running interpreter
                     # in Python 3
                     for file_resource in alert_actions.find_exes(alert.name):
-                        _check_python_version_in_alert_action(alert,
-                                                            file_resource,
-                                                            reporter,
-                                                            filename)
+                        _check_python_version_in_alert_action(
+                            alert, file_resource, reporter, filename
+                        )
 
                 # a) is there a cross plat file (.py, .js) in default/bin?
                 if alert.count_cross_plat_exes() > 0:
@@ -132,14 +124,14 @@ def check_alert_actions_exe_exist(app, reporter, included_tags, target_splunk_ve
                     reporter_output = (
                         "The specific architecture"
                         " executables for the alert"
-                        " action {} should be"
-                        " verified."
-                    ).format(alert.name)
+                        f" action {alert.name} should"
+                        " be verified."
+                    )
                     reporter.manual_check(reporter_output, filename, alert.lineno)
                 else:
                     reporter_output = (
-                        "No executable was found for alert" " action {}."
-                    ).format(alert.name)
+                        f"No executable was found for alert action {alert.name}."
+                    )
                     if "cloud" in included_tags:
                         reporter.warn(reporter_output, filename, alert.lineno)
                     else:
@@ -161,8 +153,8 @@ def check_workflow_html_exists_for_custom_alert(app, reporter):
             if not alert.workflow_html().exists():
                 reporter_output = (
                     "No HTML file was found at default/data/ui/alerts/"
-                    " for {}. File: {}, Line: {}."
-                ).format(alert.relative_workflow_html_path, filename, alert.lineno)
+                    f" for {alert.relative_workflow_html_path}. File: {filename}, Line: {alert.lineno}."
+                )
                 reporter.fail(reporter_output, filename, alert.lineno)
 
 
@@ -186,8 +178,8 @@ def check_for_payload_format(app, reporter):
                         reporter_output = (
                             "The alert action must specify"
                             " either 'json' or 'xml' as the"
-                            " payload. File: {}, Line: {}."
-                        ).format(filename, lineno)
+                            f" payload. File: {filename}, Line: {lineno}."
+                        )
                         reporter.fail(reporter_output, filename, lineno)
 
 
@@ -204,35 +196,39 @@ def check_for_explict_exe_args(app, reporter):
                     lineno = alert.args[arg][1]
                     reporter_output = (
                         "The alert action specifies executable arguments: "
-                        " {}, Manually verify these arguments"
+                        f" {arg}, Manually verify these arguments"
                         " against the executable."
-                        " File: {}, Line: {}."
-                    ).format(arg, filename, lineno)
+                        f" File: {filename}, Line: {lineno}."
+                    )
                     reporter.manual_check(reporter_output, filename, lineno)
 
 
-def _check_python_version_in_alert_action(alert, file_resource, reporter, config_file_path):
+def _check_python_version_in_alert_action(
+    alert, file_resource, reporter, config_file_path
+):
     if file_resource.file_path.endswith("py"):
         if alert.python_version == "python3":
             import ast
+
             if sys.version_info >= (3,):
                 fd = open(file_resource.file_path)
                 try:
                     ast.parse(fd.read())
                 except Exception:
                     reporter.fail(
-                        "Alert action `{}` calls a script that is not Python 3 compatible, "
-                        "Please upgrade your Python script to be Python 3 compatible.".format(alert.name),
-                        file_resource.app_file_path)
+                        f"Alert action `{alert.name}` calls a script that is not Python 3 compatible, "
+                        "Please upgrade your Python script to be Python 3 compatible.",
+                        file_resource.app_file_path,
+                    )
             else:
                 # Do nothing because the interpreter is not Python 3
                 pass
         else:
             reporter_output = (
-                " The `alert_actions.conf` stanza [{}] is using python script as alert script."
+                f" The `alert_actions.conf` stanza [{alert.name}] is using python script as alert script."
                 " but not specifying `python.version=python3`. Please specify `python.version=python3.`"
-                ).format(alert.name)
+            )
             reporter.fail(reporter_output, config_file_path)
     else:
         # Do nothing because it's not Python script
-        pass
\ No newline at end of file
+        pass
