@@ -6,24 +6,22 @@
 Ensure that the directories and files in the app adhere to hierarchy standards.
 """
 
-# Python Standard Libraries
 import logging
 import os
 import re
 import string
 
-# Third-Party Libraries
-# N/A
-# Custom Libraries
 import splunk_appinspect
-from splunk_appinspect.splunk import normalizeBoolean
 from splunk_appinspect.common.file_hash import md5
+from splunk_appinspect.splunk import normalizeBoolean
 
 report_display_order = 2
 logger = logging.getLogger(__name__)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "appapproval", "cloud", "self-service", "private_app")
+@splunk_appinspect.tags(
+    "splunk_appinspect", "appapproval", "cloud", "self-service", "private_app"
+)
 @splunk_appinspect.cert_version(min="1.0.0")
 @splunk_appinspect.display(report_display_order=1)
 def check_that_local_does_not_exist(app, reporter):
@@ -45,8 +43,8 @@ def check_for_local_meta(app, reporter):
         file_path = os.path.join("metadata", "local.meta")
         reporter_output = (
             "Do not supply a local.meta file- put all settings"
-            " in default.meta. File: {}"
-        ).format(file_path)
+            f" in default.meta. File: {file_path}"
+        )
         reporter.fail(reporter_output, file_path)
 
 
@@ -61,8 +59,8 @@ def check_that_local_passwords_conf_does_not_exist(app, reporter):
             file_path = os.path.join("local", "passwords.conf")
             reporter_output = (
                 "A 'passwords.conf' file exists in the 'local'"
-                " directory of the app. File: {}"
-            ).format(file_path)
+                f" directory of the app. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
         else:
             pass  # No passwords.conf so it passes
@@ -76,7 +74,7 @@ def check_that_local_passwords_conf_does_not_exist(app, reporter):
 def check_that_directory_name_matches_package_id(app, reporter, included_tags):
     """Check that when decompressed the Splunk app directory name matches the `id` property
     in the [package] stanza in `app.conf`.
-    For Cloud apps, the `id` property must exist and match the app directory name. 
+    For Cloud apps, the `id` property must exist and match the app directory name.
     For on-premise apps, if the `id` property exists, it must match the app directory name;
     if there is no `id` property, `check_for_updates` must be set to False in `app.conf` for the check to pass.
     """
@@ -96,17 +94,11 @@ def check_that_directory_name_matches_package_id(app, reporter, included_tags):
                     # Fail, app id is present but id does not match directory name
                     lineno = package_configuration_section.get_option("id").lineno
                     reporter_output = (
-                        "The `app.conf` [package] stanza has an"
-                        " `id` property that does not match the"
-                        " uncompressed directory's name."
-                        " `app.conf` [package] id: {}"
-                        " uncompressed directory name: {}."
-                        " File: {}, Line: {}."
-                    ).format(
-                        package_stanza_id_property,
-                        uncompressed_directory_name,
-                        filename,
-                        lineno,
+                        "The `app.conf` [package] stanza has an `id` property"
+                        " that does not match the uncompressed directory's name."
+                        f" `app.conf` [package] id: {package_stanza_id_property}"
+                        f" uncompressed directory name: {uncompressed_directory_name}."
+                        f" File: {filename}, Line: {lineno}."
                     )
                     reporter.fail(reporter_output, filename, lineno)
             else:  # without package id
@@ -117,8 +109,8 @@ def check_that_directory_name_matches_package_id(app, reporter, included_tags):
                     reporter_output = (
                         "No `id` property found in [package] stanza. "
                         "Please add a valid `id`. "
-                        "File: {}, Line: {}."
-                    ).format(filename, lineno)
+                        f"File: {filename}, Line: {lineno}."
+                    )
                     reporter.fail(reporter_output, filename, lineno)
 
                 elif not package_configuration_section.has_option(
@@ -139,8 +131,8 @@ def check_that_directory_name_matches_package_id(app, reporter, included_tags):
                         "but no `id` property is defined. Please disable "
                         "`check_for_updates` or set the `id` property "
                         "to the uncompressed directory name of the app. "
-                        "File: {}, Line: {}."
-                    ).format(filename, lineno)
+                        f"File: {filename}, Line: {lineno}."
+                    )
                     reporter.fail(reporter_output, filename, lineno)
         else:  # without [package] stanza
             # Fail, the package stanza doesn't exist.
@@ -149,15 +141,15 @@ def check_that_directory_name_matches_package_id(app, reporter, included_tags):
                 reporter_output = (
                     "The `app.conf` [package] stanza does not exist. "
                     "Please add [package] stanza with valid `id` property. "
-                    "File: {}"
-                ).format(filename)
+                    f"File: {filename}"
+                )
             else:
                 reporter_output = (
                     "The `app.conf` [package] stanza does not "
                     "exist. Please disable `check_for_updates` "
                     "or set the `id` property in the [package] "
-                    "stanza. File: {}"
-                ).format(filename)
+                    f"stanza. File: {filename}"
+                )
             reporter.fail(reporter_output, filename)
     else:
         reporter_output = "No app.conf file was detected."
@@ -186,9 +178,7 @@ def check_filenames_for_spaces(app, reporter):
             filename = os.path.join(directory, file)
             # The regex that extracts the filename would extract wrong file name due to the space,
             # so here I use `Filename: {}`.
-            reporter_output = "A conf or dashboard file contains a space in the filename. Filename: {}".format(
-                filename
-            )
+            reporter_output = f"A conf or dashboard file contains a space in the filename. Filename: {filename}"
             reporter.fail(reporter_output)
 
 
@@ -218,6 +208,7 @@ def check_splunklib_dependency_under_bin_folder(app, reporter):
         "094c9718010b4703e399843ecd48cbfe",
         "ac583c645b99368f9ba51ab2e6d01597",
         "f75aa820dfa1e8227039f5fc059100d2",
+        "6ce57eec703ace22df6034576f60a5b4",
     }
     for directory, file, _ in app.iterate_files(basedir="bin", types=[".py"]):
         if file == "results.py":
