@@ -5,14 +5,11 @@
 
 Custom search commands are defined in a **commands.conf** file in the **/default** directory of the app. For more, see [About writing custom search commands](http://docs.splunk.com/Documentation/Splunk/latest/Search/Aboutcustomsearchcommands) and [commands.conf](http://docs.splunk.com/Documentation/Splunk/latest/Admin/Commandsconf).
 """
-
-# Python Standard Library
 import logging
-import re
 import os
+import re
 import sys
 
-# Custom Modules
 import splunk_appinspect
 
 report_display_order = 20
@@ -53,10 +50,10 @@ def check_default_meta_exists(app, reporter):
 @splunk_appinspect.tags("splunk_appinspect", "cloud", "python3_version", "private_app")
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_command_scripts_python_version(app, reporter, target_splunk_version):
-    """Check that commands.conf must explicitly define the python.version 
+    """Check that commands.conf must explicitly define the python.version
     to be python3 for each python-scripted custom command.
     """
-    if target_splunk_version < 'splunk_8_0':
+    if target_splunk_version < "splunk_8_0":
         return
 
     custom_commands = app.get_custom_commands()
@@ -65,22 +62,24 @@ def check_command_scripts_python_version(app, reporter, target_splunk_version):
         return
     for command in custom_commands.get_commands():
         file_path = os.path.join("default", "commands.conf")
-        if (not command.chunked or command.chunked == "false") and command.file_name.endswith(".py"):
+        if (
+            not command.chunked or command.chunked == "false"
+        ) and command.file_name.endswith(".py"):
             if "python.version" not in command.args:
                 reporter.fail(
-                        "Custome command {} doesn't define python.version,"
-                        " python.version should be explicitly set to python3.".format(command.name),
-                        file_path
-                    )
+                    f"Custom command {command.name} doesn't define python.version,"
+                    " python.version should be explicitly set to python3.",
+                    file_path,
+                )
                 continue
             value, lineno = command.args["python.version"]
             if value != "python3":
                 reporter.fail(
-                        "Custome command {} doesn't define python.version as python3,"
-                        " python.version should be explicitly set to python3.".format(command.name),
-                        file_path,
-                        lineno
-                    )
+                    f"Custom command {command.name} doesn't define python.version as python3,"
+                    " python.version should be explicitly set to python3.",
+                    file_path,
+                    lineno,
+                )
                 continue
             if sys.version_info >= (3,) and len(command.v1_exes) > 0:
                 # The following logic will only take effect when running interpreter
@@ -88,15 +87,16 @@ def check_command_scripts_python_version(app, reporter, target_splunk_version):
                 python_script_resource = command.v1_exes[0]
                 if python_script_resource.exists():
                     import ast
+
                     fd = open(python_script_resource.file_path)
                     try:
                         ast.parse(fd.read())
                     except Exception:
                         reporter.fail(
-                            "Custome command {} defines a script that is not Python 3 compatible, "
-                            "Please upgrade your Python script to be Python 3 compatible.".format(command.name),
-                            os.path.join("bin", command.file_name))
-
+                            f"Custom command {command.name} defines a script that is not Python 3 compatible, "
+                            "Please upgrade your Python script to be Python 3 compatible.",
+                            os.path.join("bin", command.file_name),
+                        )
 
 
 @splunk_appinspect.tags("splunk_appinspect", "custom_search_commands", "manual")
@@ -121,10 +121,10 @@ def check_command_scripts_exist(app, reporter):
             # can't find scripts in `bin/` or `<PLATFORM>/bin`
             if not is_filename_with_path_suffix and not command.file_name_exe:
                 reporter_message = (
-                    "The script of command [{}] was not found "
+                    f"The script of command [{command.name}] was not found "
                     "or the script type is not supported. "
-                    "File: {}, Line: {}."
-                ).format(command.name, file_path, lineno)
+                    f"File: {file_path}, Line: {lineno}."
+                )
                 reporter.fail(reporter_message, file_path, lineno)
 
             # v2 command
@@ -146,9 +146,9 @@ def _check_v1_command(command, reporter):
     # file extension is not in v1 extensions
     if count_v1_exes == 0:
         reporter_message = (
-            "The stanza [{}] in commands.conf must use a .py or "
-            ".pl script. File: {}, Line: {}."
-        ).format(command.name, file_path, lineno)
+            f"The stanza [{command.name}] in commands.conf must use a .py or "
+            f".pl script. File: {file_path}, Line: {lineno}."
+        )
         reporter.fail(reporter_message, file_path, lineno)
 
 
@@ -169,21 +169,21 @@ def _check_v2_command(command, reporter, is_filename_with_path_suffix):
         lineno = command.args["filename"][1]
         reporter_message = (
             "The custom command is chunked and "
-            "the stanza [{}] in commands.conf has field of "
+            f"the stanza [{command.name}] in commands.conf has field of "
             "`filename` with value ends with `.path`. "
             "Please manual check whether this path pointer files "
             "are inside of app container and use relative path. "
-            "File: {}, Line: {}."
-        ).format(command.name, file_path, lineno)
+            f"File: {file_path}, Line: {lineno}."
+        )
         reporter.manual_check(reporter_message, file_path, lineno)
     # file extension is not in v2 extensions
     elif count_v2_exes == 0:
         reporter_message = (
             "Because the custom command is chunked, "
-            "the stanza [{}] in commands.conf must use a .py, "
+            f"the stanza [{command.name}] in commands.conf must use a .py, "
             ".pl, .cmd, .bat, .exe, .js, .sh or no extension "
-            "script. File: {}, Line: {}."
-        ).format(command.name, file_path, lineno)
+            f"script. File: {file_path}, Line: {lineno}."
+        )
         reporter.fail(reporter_message, file_path, lineno)
 
 
@@ -211,10 +211,10 @@ def check_ignored_parameters_v2_command(app, reporter):
                     if rex.search(a.lower()) is None:
                         lineno = command.args[a][1]
                         reporter_message = (
-                            "The setting {} is not supported because"
-                            " chunked is set to be true in the"
-                            " command : {}. File: {}, Line: {}."
-                        ).format(a, command.name, file_path, lineno)
+                            f"The setting {a} is not supported because chunked"
+                            f" is set to be true in the command : {command.name}."
+                            f" File: {file_path}, Line: {lineno}."
+                        )
                         reporter.fail(reporter_message, file_path, lineno)
     else:
         reporter.not_applicable("No `commands.conf` file exists.")
@@ -241,10 +241,10 @@ def check_ignored_parameters_v1_command(app, reporter):
                     if a in ("maxwait", "maxchunksize"):
                         lineno = command.args[a][1]
                         reporter_message = (
-                            "The field {} will be ignored because"
-                            " chunked is not specified in the"
-                            " command : {}. File: {}, Line: {}."
-                        ).format(a, command.name, file_path, lineno)
+                            f"The field {a} will be ignored because chunked is"
+                            f" not specified in the command : {command.name}."
+                            f" File: {file_path}, Line: {lineno}."
+                        )
                         reporter.fail(reporter_message, file_path, lineno)
     else:
         reporter.not_applicable("No `commands.conf` file exists.")
@@ -271,9 +271,9 @@ def check_passauth_and_enableheader(app, reporter):
                     lineno = command.args["enableheader"][1]
                     reporter_message = (
                         "Because enableheader is not set to true,"
-                        " passauth will be ignored for"
-                        " {}. File: {}, Line: {}."
-                    ).format(command.name, file_path, lineno)
+                        f" passauth will be ignored for {command.name}."
+                        f" File: {file_path}, Line: {lineno}."
+                    )
                     reporter.warn(reporter_message, file_path, lineno)
 
 
@@ -300,9 +300,9 @@ def check_requires_srinfo_and_enableheader(app, reporter):
                     lineno = command.args["enableheader"][1]
                     reporter_message = (
                         "Because enableheader is not set to true,"
-                        " requires_srinfo will be ignored for"
-                        " {}. File: {}, Line: {}."
-                    ).format(command.name, file_path, lineno)
+                        f" requires_srinfo will be ignored for {command.name}."
+                        f" File: {file_path}, Line: {lineno}."
+                    )
                     reporter.warn(reporter_message, file_path, lineno)
 
 
@@ -311,7 +311,7 @@ def check_requires_srinfo_and_enableheader(app, reporter):
 )
 @splunk_appinspect.cert_version(min="1.1.7")
 def check_requires_preop_and_streaming_preop(app, reporter):
-    """ Check that custom search commands using `requires_preop` have
+    """Check that custom search commands using `requires_preop` have
     `streaming_preop` set to true.
     """
     custom_commands = app.get_custom_commands()
@@ -325,7 +325,7 @@ def check_requires_preop_and_streaming_preop(app, reporter):
                     lineno = command.args["requires_preop"][1]
                     reporter_message = (
                         "Because requires_preop is not set to true,"
-                        " streaming_preop will be ignored for"
-                        " {}. File: {}, Line: {}."
-                    ).format(command.name, file_path, lineno)
+                        f" streaming_preop will be ignored for {command.name}."
+                        f" File: {file_path}, Line: {lineno}."
+                    )
                     reporter.warn(reporter_message, file_path, lineno)
