@@ -6,25 +6,21 @@
 Custom visualizations are defined in **/default/visualizations.conf** file. For more, see [Custom visualization API reference](http://docs.splunk.com/Documentation/Splunk/latest/AdvancedDev/CustomVizApiRef).
 """
 
-# Python Standard Library
 import logging
 import os
 import re
 
-# Third-Party Support
-# N/A
-# Custom
-# N/A
 import bs4
 from six import iteritems
 from six.moves.urllib.parse import unquote
+
 import splunk_appinspect
-from splunk_appinspect.image_resource import ImageResource
-from splunk_appinspect.custom_visualizations import (
-    CustomVisualizations,
-    CustomVisualization,
-)
 from splunk_appinspect.configuration_file import NoOptionError
+from splunk_appinspect.custom_visualizations import (
+    CustomVisualization,
+    CustomVisualizations,
+)
+from splunk_appinspect.image_resource import ImageResource
 
 logger = logging.getLogger(__name__)
 
@@ -45,15 +41,13 @@ def check_for_visualizations_preview_png(app, reporter):
                 ) in custom_visualizations_component.get_custom_visualizations():
                     _check_preview_png_for_mod_viz(reporter, app, mod_viz)
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
 
         else:
             visualizations_dir = CustomVisualizations.visualizations_directory()
             visualizations_folder_not_exist_message = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}".format(
-                    visualizations_dir, file_path
-                )
+                f"The `{visualizations_dir}` directory does not exist, which is "
+                f"required for the visualizations.conf. File: {file_path}"
             )
             reporter.fail(visualizations_folder_not_exist_message, file_path)
     else:
@@ -66,20 +60,17 @@ def _check_preview_png_for_mod_viz(reporter, app, mod_viz):
     file_path = os.path.join("default", "visualizations.conf")
     if not mod_viz.does_visualization_directory_exist():
         vis_dir_not_exist_message = (
-            "The directory {} doesn't exist for this visualization {}."
-            "File: {}, Line: {}.".format(
-                visualization_dir, mod_viz.name, file_path, mod_viz.lineno
-            )
+            f"The directory {visualization_dir} doesn't "
+            f"exist for this visualization {mod_viz.name}."
+            f"File: {file_path}, Line: {mod_viz.lineno}."
         )
         reporter.fail(vis_dir_not_exist_message, file_path, mod_viz.lineno)
     else:
         if not mod_viz.does_preview_png_exist():
             preview_file_not_exist_message = (
-                "The required preview.png file doesn't exist "
-                "under folder {} for visualization {}. File: {}, "
-                "Line: {}.".format(
-                    visualization_dir, mod_viz.name, file_path, mod_viz.lineno
-                )
+                "The required preview.png file doesn't exist under folder "
+                f"{visualization_dir} for visualization {mod_viz.name}. "
+                f"File: {file_path}, Line: {mod_viz.lineno}."
             )
             reporter.fail(preview_file_not_exist_message, file_path, mod_viz.lineno)
         else:
@@ -93,11 +84,9 @@ def _check_png_dimension(reporter, visualization_dir, preview_png_path):
         preview_png_resource = ImageResource(preview_png_path)
         if not preview_png_resource.is_png():
             invalid_png_message = (
-                "The preview.png file under folder {} doesn't "
-                "appear to be a valid png file. Its content type is {}. "
-                "File: {}".format(
-                    visualization_dir, preview_png_resource.content_type(), file_path
-                )
+                f"The preview.png file under folder {visualization_dir} doesn't appear to be "
+                f"a valid png file. Its content type is {preview_png_resource.content_type()}. "
+                f"File: {file_path}"
             )
             reporter.fail(invalid_png_message, file_path)
         else:
@@ -105,22 +94,14 @@ def _check_png_dimension(reporter, visualization_dir, preview_png_path):
             expected_dimension = CustomVisualization.valid_preview_png_dimensions()
             if not image_dimension == expected_dimension:
                 invalid_preview_png_size_message = (
-                    "The preview.png image dimension is {}x{}, "
-                    "but {}x{} is expected. File: {}".format(
-                        image_dimension[0],
-                        image_dimension[1],
-                        expected_dimension[0],
-                        expected_dimension[1],
-                        file_path,
-                    )
+                    f"The preview.png image dimension is {image_dimension[0]}x{image_dimension[1]}, "
+                    f"but {expected_dimension[0]}x{expected_dimension[1]} is expected. File: {file_path}"
                 )
                 reporter.fail(invalid_preview_png_size_message, file_path)
     except NotImplementedError:
         invalid_png_message = (
-            "The preview.png file under folder {} doesn't "
-            "appear to be a valid png file. File: {}".format(
-                visualization_dir, file_path
-            )
+            f"The preview.png file under folder {visualization_dir} doesn't "
+            f"appear to be a valid png file. File: {file_path}"
         )
         reporter.fail(invalid_png_message, file_path)
 
@@ -138,9 +119,9 @@ def check_for_visualizations_directory(app, reporter):
             pass  # Success, Directory exists
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not exist, "
+                f"which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter_output = "visualizations.conf does not exist."
@@ -167,23 +148,24 @@ def check_that_visualizations_conf_has_matching_default_meta_stanza(app, reporte
                     for custom_visualization in custom_visualizations.get_custom_visualizations()
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 default_meta_stanza_names = [
                     stanza_name for stanza_name in default_meta.section_names()
                 ]
 
                 for visualizations_conf_stanza_name in visualizations_conf_stanza_names:
-                    expected_default_meta_stanza_name = ("visualizations/{}").format(
-                        visualizations_conf_stanza_name
+                    expected_default_meta_stanza_name = (
+                        f"visualizations/{visualizations_conf_stanza_name}"
                     )
                     if (
                         expected_default_meta_stanza_name
                         not in default_meta_stanza_names
                     ):
                         reporter_output = (
-                            "No [{}] stanza found in default.meta. " "File: {}"
-                        ).format(expected_default_meta_stanza_name, default_meta_path)
+                            f"No [{expected_default_meta_stanza_name}] stanza found in default.meta. "
+                            f"File: {default_meta_path}"
+                        )
                         reporter.warn(reporter_output, default_meta_path)
         else:
             try:
@@ -193,16 +175,16 @@ def check_that_visualizations_conf_has_matching_default_meta_stanza(app, reporte
                 ]
 
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 for stanza in stanzas:
                     reporter_output = (
                         "visualizatsions.conf was detected, but no"
                         " default.meta file was detected. Please add"
                         " a default.meta file. Please declare the stanza"
-                        " [{}] declared and the desired permissions set."
-                        " File: {}, Line: {}."
-                    ).format(stanza.name, visualizations_conf_path, stanza.lineno)
+                        f" [{stanza.name}] declared and the desired permissions set."
+                        f" File: {visualizations_conf_path}, Line: {stanza.lineno}."
+                    )
                     reporter.warn(
                         reporter_output, visualizations_conf_path, stanza.lineno
                     )
@@ -229,19 +211,14 @@ def check_for_matching_stanza_visualization_directory(app, reporter):
                     if not custom_visualization.does_visualization_directory_exist()
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 for visualization_without_directory in visualizations_without_directory:
                     reporter_output = (
-                        "The stanza [{}] does not have a corresponding"
-                        " directory at `{}`. Please add the"
-                        " visualization directory and its corresponding"
-                        " files. File: {}, Line: {}."
-                    ).format(
-                        visualization_without_directory.name,
-                        visualization_without_directory.visualization_directory(),
-                        file_path,
-                        visualization_without_directory.lineno,
+                        f"The stanza [{visualization_without_directory.name}] does not have a corresponding"
+                        f" directory at `{visualization_without_directory.visualization_directory()}`. "
+                        " Please add the visualization directory and its corresponding files. "
+                        f" File: {file_path}, Line: {visualization_without_directory.lineno}."
                     )
                     reporter.fail(
                         reporter_output,
@@ -250,9 +227,9 @@ def check_for_matching_stanza_visualization_directory(app, reporter):
                     )
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not "
+                f"exist, which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter_output = "visualizations.conf does not exist."
@@ -280,7 +257,7 @@ def check_for_required_files_for_visualization(app, reporter):
                     )
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 for visualization in visualizations_with_directory:
                     missing_files = [
@@ -295,20 +272,15 @@ def check_for_required_files_for_visualization(app, reporter):
                     for missing_file in missing_files:
                         reporter_output = (
                             "Required custom visualization file not found: "
-                            "appserver/static/visualizations/{}/{}. File: {},"
-                            "Line: {}."
-                        ).format(
-                            visualization.name,
-                            missing_file,
-                            file_path,
-                            visualization.lineno,
+                            f"appserver/static/visualizations/{visualization.name}/{missing_file}. "
+                            f"File: {file_path},Line: {visualization.lineno}."
                         )
                         reporter.fail(reporter_output, file_path, visualization.lineno)
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not "
+                f"exist, which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter_output = "visualizations.conf does not exist."
@@ -336,7 +308,7 @@ def check_for_formatter_html_comments(app, reporter):
                     )
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 for visualization in visualizations_with_formatter_html:
                     formatter_html_relative_path = os.path.join(
@@ -364,14 +336,14 @@ def check_for_formatter_html_comments(app, reporter):
                             "A custom visualization html file contains html"
                             " comments, which will be removed during Splunk run-time."
                             " Please consider removing the comments."
-                            " file:{} comment:{}"
-                        ).format(formatter_html_relative_path, comment_content)
+                            f" file:{formatter_html_relative_path} comment:{comment_content}"
+                        )
                         reporter.warn(reporter_output, formatter_html_relative_path)
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not "
+                f"exist, which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter_output = "visualizations.conf does not exist."
@@ -399,7 +371,7 @@ def check_for_formatter_html_bad_nodes(app, reporter):
                     )
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 for visualization in visualizations_with_formatter_html:
                     formatter_html_relative_path = os.path.join(
@@ -418,30 +390,29 @@ def check_for_formatter_html_bad_nodes(app, reporter):
                         content = b"<div>" + content + b"</div>"
                     soup = bs4.BeautifulSoup(content, "lxml-xml")
 
-                    reporter_output_pattern = (
-                        "A custom visualization html file contains tags"
-                        " that will be removed during Splunk run-time."
-                        " Please consider removing the tags."
-                        " file:{} tag:{}"
-                    )
-
                     for tag_name in ["script", "link", "meta", "head"]:
                         for tag in soup.find_all(tag_name):
-                            reporter_output = reporter_output_pattern.format(
-                                formatter_html_relative_path, tag.prettify()
+                            reporter_output = (
+                                "A custom visualization html file contains tags"
+                                " that will be removed during Splunk run-time."
+                                " Please consider removing the tags."
+                                f" file:{formatter_html_relative_path} tag:{tag.prettify()}"
                             )
                             reporter.warn(reporter_output, formatter_html_relative_path)
 
                     for tag in soup.find_all(type="text/javascript"):
-                        reporter_output = reporter_output_pattern.format(
-                            formatter_html_relative_path, tag.prettify()
+                        reporter_output = (
+                            "A custom visualization html file contains tags"
+                            " that will be removed during Splunk run-time."
+                            " Please consider removing the tags."
+                            f" file:{formatter_html_relative_path} tag:{tag.prettify()}"
                         )
                         reporter.warn(reporter_output, formatter_html_relative_path)
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not "
+                f"exist, which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter_output = "visualizations.conf does not exist."
@@ -479,7 +450,7 @@ def check_for_formatter_html_inappropriate_attributes(app, reporter):
                     )
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 for visualization in visualizations_with_formatter_html:
                     formatter_html_relative_path = os.path.join(
@@ -501,15 +472,13 @@ def check_for_formatter_html_inappropriate_attributes(app, reporter):
                     for tag in soup.find_all():
                         tag_name = tag.name.lower() if tag.name else "".lower()
                         for attr_name, attr_val in iteritems(tag.attrs):
-                            attr_str = '{}="{}"'.format(attr_name, attr_val)
+                            attr_str = f'{attr_name}="{attr_val}"'
                             if attr_name.lower().find("on") == 0:
                                 reporter_output = (
                                     "A custom visualization html contains html that"
                                     " has inappropriate attributes. These attributes are replaced"
                                     " during Splunk run-time. Please consider removing the attributes."
-                                    " file:{} tag:{} attribute:{}"
-                                ).format(
-                                    formatter_html_relative_path, tag.name, attr_str
+                                    f" file:{formatter_html_relative_path} tag:{tag.name} attribute:{attr_str}"
                                 )
                                 reporter.warn(
                                     reporter_output, formatter_html_relative_path
@@ -525,18 +494,16 @@ def check_for_formatter_html_inappropriate_attributes(app, reporter):
                                     "A custom visualization html file contains html that"
                                     " has inappropriate attributes. These attributes are removed"
                                     " during Splunk run-time. Please consider removing the attributes."
-                                    " file:{} tag:{} attribute:{}"
-                                ).format(
-                                    formatter_html_relative_path, tag.name, attr_str
+                                    f" file:{formatter_html_relative_path} tag:{tag.name} attribute:{attr_str}"
                                 )
                                 reporter.warn(
                                     reporter_output, formatter_html_relative_path
                                 )
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not "
+                f"exist, which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter_output = "visualizations.conf does not exist."
@@ -578,7 +545,7 @@ def check_for_formatter_html_css_expressions(app, reporter):
                     )
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 for visualization in visualizations_with_formatter_html:
                     formatter_html_relative_path = os.path.join(
@@ -612,18 +579,15 @@ def check_for_formatter_html_css_expressions(app, reporter):
                             " has css expressions. These css expressions are"
                             " replaced during Splunk run-time. Please consider"
                             "removing the css expressions."
-                            " file: {} tag: {} css_expression: {}"
-                        ).format(
-                            formatter_html_relative_path,
-                            style_tag.name,
-                            style_tag.string,
+                            f" file: {formatter_html_relative_path} tag: {style_tag.name}"
+                            f" css_expression: {style_tag.string}"
                         )
                         reporter.warn(reporter_output, formatter_html_relative_path)
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not "
+                f"exist, which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter_output = "visualizations.conf does not exist."
@@ -652,7 +616,7 @@ def check_for_formatter_html_inline_style_attributes(app, reporter):
                     )
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 for visualization in visualizations_with_formatter_html:
                     formatter_html_relative_path = os.path.join(
@@ -680,16 +644,15 @@ def check_for_formatter_html_inline_style_attributes(app, reporter):
                             " has inline style attributes for style tags. These"
                             "attributes are removed during Splunk run-time."
                             "Please consider removing the css expressions."
-                            " file:{} tag:{} attribute:{}"
-                        ).format(
-                            formatter_html_relative_path, style_tag.name, style_attr
+                            f" file:{formatter_html_relative_path} tag:{style_tag.name}"
+                            f" attribute:{style_attr}"
                         )
                         reporter.warn(reporter_output, formatter_html_relative_path)
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not "
+                f"exist, which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
     else:
         reporter_output = "visualizations.conf does not exist."
@@ -716,7 +679,7 @@ def check_for_default_values_for_modviz(app, reporter):
                     )
                 ]
             except NoOptionError as error:
-                reporter.fail("required option is missing, {}".format(str(error)))
+                reporter.fail(f"required option is missing, {str(error)}")
             else:
                 if app.file_exists("README", "savedsearches.conf.spec"):
                     file_path = os.path.join("README", "savedsearches.conf.spec")
@@ -732,12 +695,8 @@ def check_for_default_values_for_modviz(app, reporter):
                         if k.startswith("display.visualizations.custom.")
                     ]
                     for viz in custom_vizs:
-                        identify = "{app}.{viz}".format(
-                            app=custom_visualizations.app.name, viz=viz.name
-                        )
-                        property_prefix = "display.visualizations.custom.{identify}.".format(
-                            identify=identify
-                        )
+                        identify = f"{custom_visualizations.app.name}.{viz.name}"
+                        property_prefix = f"display.visualizations.custom.{identify}."
                         viz_option_spec = [
                             k
                             for k in modviz_options
@@ -749,8 +708,8 @@ def check_for_default_values_for_modviz(app, reporter):
                                 file_path = os.path.join(
                                     "default", "savedsearches.conf"
                                 )
-                                reporter_output = "default stanza is not found in file: {}".format(
-                                    file_path
+                                reporter_output = (
+                                    f"default stanza is not found in file: {file_path}"
                                 )
                                 reporter.fail(reporter_output, file_path)
                             else:
@@ -758,17 +717,17 @@ def check_for_default_values_for_modviz(app, reporter):
                                 for option, lineno in viz_option_spec:
                                     if not default_section.has_option(option):
                                         reporter_output = (
-                                            "mod viz option {} should have a default value "
-                                            "in default/savedsearches.conf. File: {}, Line: {}."
-                                        ).format(option, file_path, lineno)
+                                            f"mod viz option {option} should have a default value in "
+                                            f"default/savedsearches.conf. File: {file_path}, Line: {lineno}."
+                                        )
                                         reporter.fail(
                                             reporter_output, file_path, lineno
                                         )
         else:
             reporter_output = (
-                "The `{}` directory does not exist, which is "
-                "required for the visualizations.conf. File: {}"
-            ).format(CustomVisualizations.visualizations_directory(), file_path)
+                f"The `{CustomVisualizations.visualizations_directory()}` directory does not "
+                f"exist, which is required for the visualizations.conf. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
 
     else:
