@@ -3,19 +3,14 @@
 """
 ### JSON file standards
 """
-
-# Python Standard Library
 import json
-import os
 import logging
+import os
 
-# Third-Party Libraries
 import six
 
-# Custom Modules
 import splunk_appinspect
 
-
 logger = logging.getLogger(__name__)
 report_display_order = 13
 
@@ -39,7 +34,5 @@ def check_validate_json_data_is_well_formed(app, reporter):
         try:
             json.loads(current_file_contents)
         except (TypeError, ValueError) as error:
-            reporter_output = (
-                "Malformed JSON file found. " "File: {} " "Error: {}"
-            ).format(current_file_relative_path, str(error))
+            reporter_output = f"Malformed JSON file found. File: {current_file_relative_path}  Error: {str(error)}"
             reporter.fail(reporter_output, current_file_relative_path)
