@@ -5,16 +5,13 @@
 
 Ensure that all meta files located in the **/metadata** folder are well formed and valid.
 """
-
-# Python Standard Library
 import collections
 import logging
 import os
 
-# Custom Libraries
-import splunk_appinspect
 from six import iteritems
 
+import splunk_appinspect
 
 report_display_order = 2
 logger = logging.getLogger(__name__)
@@ -38,9 +35,7 @@ def check_validate_no_duplicate_stanzas_in_meta_files(app, reporter):
     for key, linenos in iteritems(stanzas_found):
         if len(linenos) > 1:
             for lineno in linenos:
-                reporter_output = (
-                    "Duplicate {} stanzas were found. " "File: {}, Line: {}."
-                ).format(key[1], key[0], lineno)
+                reporter_output = f"Duplicate {key[1]} stanzas were found. File: {key[0]}, Line: {lineno}."
                 reporter.fail(reporter_output, key[0], lineno)
 
 
@@ -55,6 +50,7 @@ def check_meta_file_parsing(app, reporter):
         meta = app.get_meta(file, directory=directory)
         for err, line, section in meta.errors:
             reporter_output = (
-                "{0} at line {1} in [{2}] of {3}." " File: {4}, Line: {1}."
-            ).format(err, line, section, file, file_path)
+                f"{err} at line {line} in [{section}] of {file}."
+                " File: {file_path}, Line: {line}."
+            )
             reporter.fail(reporter_output, file_path, line)
