@@ -3,107 +3,32 @@
 """
 ### Python file standards
 """
-# Python Standard Library
 import ast
 import logging
 import os
 import platform
 import re
 
-import splunk_appinspect
+import six
+from six import iteritems
 
-# Third-Party
-# N/A
-# Custom Modules
-from splunk_appinspect.python_analyzer import utilities
-from splunk_appinspect.python_analyzer.ast_info_query import Any
-from splunk_appinspect.python_analyzer.ast_types import AstVariable
+import splunk_appinspect
 from splunk_appinspect.check_routine.python_ast_searcher.ast_searcher import AstSearcher
 from splunk_appinspect.check_routine.python_ast_searcher.node_filters import (
     is_sub_class_def,
 )
+from splunk_appinspect.python_analyzer import utilities
+from splunk_appinspect.python_analyzer.ast_info_query import Any
+from splunk_appinspect.python_analyzer.ast_types import AstVariable
 from splunk_appinspect.python_modules_metadata.metadata_common import metadata_consts
 from splunk_appinspect.python_modules_metadata.python_modules_metadata_store import (
     metadata_store,
 )
-from six import iteritems
-import six
 
 logger = logging.getLogger(__name__)
 
 report_display_order = 40
 
-
-@splunk_appinspect.tags("cloud", "manual", "ast")
-@splunk_appinspect.cert_version(min="1.7")
-def check_for_hidden_python_files(app, reporter):
-    """Check that there are no hidden python files included in the app."""
-    if platform.system() == "Windows":
-        reporter_output = "Please manual check this file to check if it is a hidden python file. File: {}"
-        for directory, file, _ in app.iterate_files(excluded_types=[".py"]):
-            current_file_relative_path = os.path.join(directory, file)
-            reporter.manual_check(
-                reporter_output.format(current_file_relative_path),
-                file_name=current_file_relative_path,
-            )
-    else:
-        reporter_output = "Hidden python script found. File: {}"
-        client = app.python_analyzer_client
-        for filepath in client.get_hidden_python_files():
-            if six.PY2:
-                content = open(os.path.join(app.app_temp_dir, filepath), "rU").read()
-            else:
-                import chardet
-
-                byte_string = open(
-                    os.path.join(app.app_temp_dir, filepath), "rb"
-                ).read()
-                encoding = chardet.detect(byte_string)["encoding"]
-                content = open(
-                    os.path.join(app.app_temp_dir, filepath), "r", encoding=encoding
-                ).read()
-            content = re.sub("[\r\n]+", " ", content)
-
-            # this check only focus on python template code
-            network_patterns = "(urllib|socket|httplib|requests|smtplib|ftplib|nntplib|poplib|imaplib|telnetlib|gopherlib|xmlrpclib|SimpleHTTPServer|SimpleXMLRPCServer)"
-            system_modules = "(subprocess|shutil|os|sys|distutils|threading|multiprocessing|commands)"
-            from_import_modules = r"from\s+import\s+{}".format(system_modules)
-            import_modules = r"import\s+{}".format(system_modules)
-            file_manipulation = r"\.(read|write|open)"
-            possible_injection = r"(subclasses|__class__|config)\.(iteritems|items)\(\)"
-            patterns = [
-                network_patterns,
-                from_import_modules,
-                import_modules,
-                file_manipulation,
-                possible_injection,
-            ]
-            template_pairs = [("<%.*", ".*%>"), ("{{.*", ".*}}"), ("{%.*", ".*%}")]
-
-            for search_pattern in [
-                pair[0] + pattern + pair[1]
-                for pattern in patterns
-                for pair in template_pairs
-            ]:
-                if re.search(search_pattern, content):
-                    reporter.manual_check(
-                        reporter_output.format(filepath), file_name=filepath
-                    )
-                    break
-
-
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
-@splunk_appinspect.cert_version(min="1.0.0")
-def check_for_compiled_python(app, reporter):
-    """Check that there are no `.pyc` or `.pyo` files included in the app."""
-    for directory, filename, _ in app.iterate_files(types=[".pyc", ".pyo"]):
-        current_file_relative_path = os.path.join(directory, filename)
-        reporter_output = "A Compiled Python file was detected. File: {}".format(
-            current_file_relative_path
-        )
-        reporter.fail(reporter_output, current_file_relative_path)
-
-
 @splunk_appinspect.tags("cloud", "ast", "private_app")
 @splunk_appinspect.cert_version(min="1.7.0")
 def check_for_possible_threading(app, reporter):
@@ -112,20 +37,6 @@ def check_for_possible_threading(app, reporter):
     whole.
     """
     client = app.python_analyzer_client
-    reporter_output = (
-        "The following line contains {} usage. "
-        "Use threading and multiprocessing with discretion."
-        " "
-        "File: {} "
-        "Line: {}"
-    )
-    reporter_output_for_loopcheck = (
-        "The following line contains questionable usage `{}` in loop. "
-        "Use threading and multiprocessing with discretion."
-        " "
-        "File: {} "
-        "Line: {}"
-    )
     circle_check_namespace = [
         "os.forkpty",
         "os.fork",
@@ -159,10 +70,15 @@ def check_for_possible_threading(app, reporter):
                     ast_info, module_name, check_object.name
                 )
                 for node in loop_nodes:
+                    reporter_output_for_loopcheck = (
+                        f"The following line contains questionable usage `{check_object.namespace}` in loop. "
+                        "Use threading and multiprocessing with discretion."
+                        " "
+                        f"File: {file_path} "
+                        f"Line: {node.lineno}"
+                    )
                     reporter.warn(
-                        reporter_output_for_loopcheck.format(
-                            check_object.namespace, file_path, node.lineno
-                        ),
+                        reporter_output_for_loopcheck,
                         file_name=file_path,
                         line_number=node.lineno,
                     )
@@ -171,10 +87,15 @@ def check_for_possible_threading(app, reporter):
                     module_name, check_object.name, lineno_only=True
                 )
                 for node_lineno in node_linenos:
+                    reporter_output = (
+                        f"The following line contains {check_object.namespace} usage. "
+                        "Use threading and multiprocessing with discretion."
+                        " "
+                        f"File: {file_path} "
+                        f"Line: {node_lineno}"
+                    )
                     reporter.warn(
-                        reporter_output.format(
-                            check_object.namespace, file_path, node_lineno
-                        ),
+                        reporter_output,
                         file_name=file_path,
                         line_number=node_lineno,
                     )
@@ -297,10 +218,11 @@ def check_all_python_files_are_well_formed(app, reporter):
     """Check all python files are well formed under python2 and python3 standard"""
 
     error_template = (
-        "Python script is not well formed, {} when parser try to parse. "
+        "Python script is not well formed, {message} when parser try to parse. "
         "Runtime errors and possible style issues could exist when it is executed. "
         "Please manual check if the whole app is broken, if yes, fail this app. "
-        "If syntax error only block part of app's functionality, warn developer to fix it. File: {}"
+        "If syntax error only block part of app's functionality, warn developer to fix it. "
+        "File: {filepath}"
     )
     syntax_error_message = "syntax error found in python script"
     null_byte_error_message = "python script contains null byte"
@@ -309,15 +231,18 @@ def check_all_python_files_are_well_formed(app, reporter):
     client = app.python_analyzer_client
     for filepath in client.get_syntax_error_files():
         reporter.manual_check(
-            error_template.format(syntax_error_message, filepath), filepath
+            error_template.format(message=syntax_error_message, filepath=filepath),
+            filepath,
         )
     for filepath in client.get_null_byte_error_files():
         reporter.manual_check(
-            error_template.format(null_byte_error_message, filepath), filepath
+            error_template.format(message=null_byte_error_message, filepath=filepath),
+            filepath,
         )
     for filepath in client.get_other_exception_files():
         reporter.manual_check(
-            error_template.format(other_exception_message, filepath), filepath
+            error_template.format(message=other_exception_message, filepath=filepath),
+            filepath,
         )
 
 
@@ -488,11 +413,6 @@ def check_for_plain_text_credentials_in_python(app, reporter):
             )
         )
 
-    reporter_output = (
-        "The following lines should be inspected during code review, "
-        "Possible plain text credentials disclosure here, `{} = {}` "
-        "File: {} Line: {}"
-    )
     client = app.python_analyzer_client
     node_to_name_dict = {}
     for filepath, ast_info in client.get_all_ast_infos():
@@ -519,13 +439,15 @@ def check_for_plain_text_credentials_in_python(app, reporter):
             )
         for sensitive_node in sensitive_ast_nodes:
             node_variable = ast_info.get_variable_details(sensitive_node)
+            reporter_output = (
+                "The following lines should be inspected during code review, "
+                "Possible plain text credentials disclosure here, "
+                f"`{node_to_name_dict[sensitive_node]} = {node_variable.variable_value}` "
+                f"File: {filepath} Line: {sensitive_node.lineno}"
+            )
+
             reporter.manual_check(
-                reporter_output.format(
-                    node_to_name_dict[sensitive_node],
-                    node_variable.variable_value,
-                    filepath,
-                    sensitive_node.lineno,
-                ),
+                reporter_output,
                 file_name=filepath,
                 line_number=sensitive_node.lineno,
             )
@@ -605,11 +527,6 @@ def check_for_generic_operating_system_services(app, reporter):
 @splunk_appinspect.cert_version(min="1.7.0")
 def check_for_reverse_shell_and_backdoor(app, reporter):
     """check if possible reverse shell exist in python code"""
-    reporter_output = (
-        "The following lines should be inspected during code review. "
-        "Possible reverse shell detected in this code block, "
-        "`subprocess` module's usage is provided. File: {}, Line: {}"
-    )
     client = app.python_analyzer_client
     for filepath, ast_info in client.get_all_ast_infos():
         # subprocess function call usage(e.g. `subprocess.call`, `subprocess.check_output`)
@@ -633,8 +550,13 @@ def check_for_reverse_shell_and_backdoor(app, reporter):
                         candidate_subprocess_usage.add(subprocess_usage)
 
         for subprocess_usage in candidate_subprocess_usage:
+            reporter_output = (
+                "The following lines should be inspected during code review. "
+                "Possible reverse shell detected in this code block, "
+                f"`subprocess` module's usage is provided. File: {filepath}, Line: {subprocess_usage.lineno}"
+            )
             reporter.manual_check(
-                reporter_output.format(filepath, subprocess_usage.lineno),
+                reporter_output,
                 file_name=filepath,
                 line_number=subprocess_usage.lineno,
             )
@@ -743,9 +665,8 @@ def check_for_ms_windows_specific_services(app, reporter):
         for module_name in ["msilib", "msvcrt", "_winreg"]:
             for lineno in ast_info.get_module_usage(module_name, lineno_only=True):
                 reporter.manual_check(
-                    "The following lines should be inspected during code review, MS Windows specific services usage `{}` has been detected".format(
-                        module_name
-                    ),
+                    "The following lines should be inspected during code review, "
+                    f"MS Windows specific services usage `{module_name}` has been detected",
                     file_name=file_path,
                     line_number=lineno,
                 )
@@ -779,9 +700,8 @@ def check_for_restricted_execution(app, reporter):
         for module_name in ["rexec", "Bastion"]:
             for lineno in ast_info.get_module_usage(module_name, lineno_only=True):
                 reporter.manual_check(
-                    "The following lines should be inspected during code review, restricted execution `{}` has been detected".format(
-                        module_name
-                    ),
+                    "The following lines should be inspected during code review, "
+                    f"restricted execution `{module_name}` has been detected",
                     file_name=file_path,
                     line_number=lineno,
                 )
