@@ -4,18 +4,16 @@
 ### Platform targets and claimed supported Splunk Enterprise versions
 """
 
+import json
+
 # Claimed Platform Targets: App must run against claimed supported Splunk
 # versions.
-# Python Standard Libraries
 import logging
 import os
 import re
-import json
 
-# Third-Party Libraries
 from jsoncomment.comments import json_preprocess
 
-# Custom Libraries
 import splunk_appinspect
 
 report_display_order = 6
@@ -60,39 +58,37 @@ def check_setup_in_distributed_environment(app, reporter):
                 reporter_output = (
                     "Inputs configuration in default/setup.xml "
                     "are not supported in distributed environments. "
-                    "File: {} "
-                ).format(file_path)
+                    f"File: {file_path} "
+                )
                 reporter.warn(reporter_output, file_path)
             else:
                 reporter_output = (
-                    "default/setup.xml exists, so manual setup in a distributed environment"
-                    " is required. File: {}"
-                ).format(file_path)
+                    "default/setup.xml exists, so manual setup in a distributed"
+                    f" environment is required. File: {file_path}"
+                )
                 reporter.manual_check(reporter_output, file_path)
         except Exception as error:
             reporter_output = (
                 "Failed to parse the file: default/setup.xml. This file might be formatted incorrectly."
-                "Exceptions: {}. File: {}"
-            ).format(str(error), file_path)
+                f"Exceptions: {str(error)}. File: {file_path}"
+            )
             reporter.fail(reporter_output, file_path)
 
     elif setup_view_option_found:
         # there exists only one custom setup view page, so if xml, no html; otherwise, no xml
         custom_setup_name = ui_section.get_option("setup_view").value
-        has_xml_file = app.file_exists(
-            "default/data/ui/views/{}.xml".format(custom_setup_name)
-        )
+        has_xml_file = app.file_exists(f"default/data/ui/views/{custom_setup_name}.xml")
         has_html_file = app.file_exists(
-            "default/data/ui/html/{}.html".format(custom_setup_name)
+            f"default/data/ui/html/{custom_setup_name}.html"
         )
         if has_xml_file or has_html_file:
             file_path = (
                 os.path.join(
-                    "default", "data", "ui", "views", "{}.xml".format(custom_setup_name)
+                    "default", "data", "ui", "views", f"{custom_setup_name}.xml"
                 )
                 if has_xml_file
                 else os.path.join(
-                    "default", "data", "ui", "html", "{}.html".format(custom_setup_name)
+                    "default", "data", "ui", "html", f"{custom_setup_name}.html"
                 )
             )
             try:
@@ -111,30 +107,28 @@ def check_setup_in_distributed_environment(app, reporter):
                     )
                 ):
                     reporter_output = (
-                        "Inputs configuration in default/data/ui/views/{}.xml are not supported in distributed"
-                        " environments. File: {}"
-                    ).format(custom_setup_name, file_path)
+                        f"Inputs configuration in default/data/ui/views/{custom_setup_name}.xml "
+                        f" are not supported in distributed environments. File: {file_path}"
+                    )
                     reporter.warn(reporter_output, file_path)
                 else:
                     reporter_output = (
                         "Custom setup page exists, "
                         "so manual setup in a distributed environment is required. "
-                        "File: {}"
-                    ).format(file_path)
+                        f"File: {file_path}"
+                    )
                     reporter.manual_check(reporter_output, file_path)
 
             except Exception as error:
                 reporter_output = (
-                    "Failed to parse the file: {0}, so it might be formatted incorrectly."
-                    "Exceptions: {1}, File: {0}"
-                ).format(file_path, str(error))
+                    f"Failed to parse the file: {file_path}, so it might be formatted incorrectly."
+                    f"Exceptions: {str(error)}, File: {file_path}"
+                )
                 reporter.fail(reporter_output, file_path)
         else:
             # this checkpoint should have been covered in separate check
             file_path = os.path.join("default", "app.conf")
-            reporter_output = (
-                "Custom setup page {} is not found in default/data/ui. File: {}"
-            ).format(custom_setup_name, file_path)
+            reporter_output = f"Custom setup page {custom_setup_name} is not found in default/data/ui. File: {file_path}"
             reporter.fail(reporter_output, file_path)
 
 
@@ -153,9 +147,7 @@ def check_that_json_schema_is_applicable(app, reporter):
     try:
         schema_version = _extract_json_schema(app_manifest_path)
     except ValueError as error:
-        reporter.fail(
-            "Malformed app.manifest file. Json loading error: {}".format(str(error))
-        )
+        reporter.fail(f"Malformed app.manifest file. Json loading error: {str(error)}")
         return
     if schema_version != "1.0.0":
         reporter_output = (
