@@ -1,15 +1,12 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
-
-# Python Standard Libraries
 import os
 import re
 
-# Custom Libraries
 import splunk_appinspect
+
 from . import commands_configuration_file
 from .file_resource import FileResource
 
-
 # http://docs.splunk.com/Documentation/Splunk/7.2.0/Search/Customcommandlocation#Platform-specific_custom_commands
 
 
@@ -159,7 +156,7 @@ class CustomCommands:
                     # This pattern is used in order to get an exact match for
                     # the name without checking length of the strings.
                     pattern = re.escape(file_name or name)
-                    file_regex_pattern = "^{}$".format(pattern)
+                    file_regex_pattern = f"^{pattern}$"
                     file_name_regex_object = re.compile(file_regex_pattern, regex_flags)
                     found_file_matching_custom_command_name = (
                         re.search(file_name_regex_object, script_name) is not None
