@@ -1,10 +1,7 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 """Splunk App Custom Visualization abstraction module"""
-
-# Python Standard Libraries
 import os
 
-# Custom
 import splunk_appinspect
 
 
@@ -44,16 +41,18 @@ class CustomVisualizations:
             else None
         )
 
-        custom_visualization = splunk_appinspect.custom_visualizations.CustomVisualization(
-            self.app,
-            stanza_section.name,
-            description_option,
-            label_option,
-            search_fragment_option,
-            stanza_section.lineno,
-            allow_user_selection=allow_user_selection_option,
-            default_height=default_height_option,
-            disabled=disabled_option,
+        custom_visualization = (
+            splunk_appinspect.custom_visualizations.CustomVisualization(
+                self.app,
+                stanza_section.name,
+                description_option,
+                label_option,
+                search_fragment_option,
+                stanza_section.lineno,
+                allow_user_selection=allow_user_selection_option,
+                default_height=default_height_option,
+                disabled=disabled_option,
+            )
         )
         return custom_visualization
 
