@@ -3,12 +3,6 @@
 """
 Helper module for documentation links generation
 """
-
-# Python Standard Libraries
-# Third-Party Libraries
-# N/A
-# Custom Libraries
-
 from splunk_appinspect.splunk_defined_conf_file_list import LATEST_CONFS
 
 
@@ -20,8 +14,10 @@ class DocumentationLinks(object):
         """Returns the Splunk Doc link for a conf file."""
         if conf_file in LATEST_CONFS:
             uri_path = conf_file.replace(".", "")
-            return "https://docs.splunk.com/Documentation/Splunk/latest/Admin/{}".format(
-                uri_path
+            return (
+                "https://docs.splunk.com/Documentation/Splunk/latest/Admin/{}".format(
+                    uri_path
+                )
             )
 
         return "Unable to find doc link for {}".format(conf_file)
