@@ -1,15 +1,10 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 
-# Standard Python Libraries
 import os
 import re
 
-# Third-Party Libraries
 import six
 
-# Custom Libraries
-# N/A
-
 
 class InspectedFile(object):
     def __init__(self, path=""):
@@ -90,13 +85,13 @@ class InspectedFile(object):
             line_no += 1
             for rx in [re.compile(p, regex_option) for p in patterns]:
                 for p_match in rx.finditer(line):
-                    fileref_output = "{}:{}".format(self._path, line_no)
+                    fileref_output = f"{self._path}:{line_no}"
                     matches.append((fileref_output, p_match))
 
         return matches
 
     def search_for_pattern(self, pattern, excluded_comments=True, regex_option=0):
-        """ Same with search_for_patterns except single pattern."""
+        """Same with search_for_patterns except single pattern."""
         return self.search_for_patterns([pattern], excluded_comments, regex_option)
 
     def search_for_crossline_patterns(
@@ -136,7 +131,7 @@ class InspectedFile(object):
 
             for rx in [re.compile(p) for p in patterns]:
                 if rx.match(multi_line):
-                    fileref_output = "{}:{}".format(self._path, line_no + 1)
+                    fileref_output = f"{self._path}:{line_no + 1}"
                     matches.append((fileref_output, rx.match(multi_line)))
 
         return matches
@@ -144,7 +139,7 @@ class InspectedFile(object):
     def search_for_crossline_pattern(
         self, pattern, excluded_comments=True, cross_line=10
     ):
-        """ Same with search_for_crossline_patterns except single pattern."""
+        """Same with search_for_crossline_patterns except single pattern."""
         return self.search_for_crossline_patterns(
             patterns=[pattern],
             excluded_comments=excluded_comments,
@@ -184,7 +179,7 @@ class PythonFile(InspectedFile):
         super(PythonFile, self).__init__(path)
 
     def _remove_comments(self, content):
-        """ Override _remove_comments."""
+        """Override _remove_comments."""
         content = "".join(
             map(
                 lambda m: self._evaluate_match(m, "code", "comments"),
@@ -232,7 +227,7 @@ class CStyleFile(InspectedFile):
         super(CStyleFile, self).__init__(path)
 
     def _remove_comments(self, content):
-        """ Override _remove_comments."""
+        """Override _remove_comments."""
         return "".join(
             map(
                 lambda m: self._evaluate_match(m, "code", "comments"),
