@@ -1,10 +1,8 @@
 # Copyright 2019 Splunk Inc. All rights reserved.
 """Splunk lookup file helper functions module"""
-
-# Python Standard Libraries
 import csv
-import sys
 import platform
+import sys
 
 if platform.system() == "Windows":
     csv.field_size_limit(int((1 << 31) - 1))
@@ -16,16 +14,16 @@ else:
 LOOKUP_HEADER_CHAR_LIMIT = 4096
 LOOKUP_EMPTY_MESSAGE = "Lookups should not be empty. Please remove this lookup."
 LOOKUP_HEADER_CHAR_LIMIT_MESSAGE = (
-    "Lookups headers should contain no more than {} characters. Please"
-    " edit/remove this lookup.".format(LOOKUP_HEADER_CHAR_LIMIT)
+    f"Lookups headers should contain no more than {LOOKUP_HEADER_CHAR_LIMIT} characters. "
+    "Please edit/remove this lookup."
 )
 LOOKUP_MAC_LINE_ENDINGS_MESSAGE = (
     "Lookups should not contain pre-OS X (OS 9 or earlier) Macintosh-style"
     " line endings. Please edit/remove this lookup."
 )
 LOOKUP_COLUMN_MISMATCH_MESSAGE = (
-    "The number of columns in row {} ({} columns) does not match the number of"
-    " columns in the csv's header ({} columns). The header is considered row"
+    "The number of columns in row {row} ({row_column} columns) does not match the number of"
+    " columns in the csv's header ({header_column} columns). The header is considered row"
     " 1. Please edit/remove this lookup."
 )
 LOOKUP_NON_UTF8_MESSAGE = (
@@ -123,10 +121,12 @@ class LookupHelper(object):
                     return (
                         False,
                         LOOKUP_COLUMN_MISMATCH_MESSAGE.format(
-                            row + 1, row_columns, header_columns
+                            row=row + 1,
+                            row_column=row_columns,
+                            header_column=header_columns,
                         ),
                     )
-        except:
+        except Exception:
             raise
         finally:
             csvfile.close()
