@@ -1,16 +1,13 @@
-# Python Standard Libraries
 import ast
+import codecs
+import logging
 import os
 import pkgutil
-import logging
 import re
-import codecs
 from collections import deque
 
-# Third-Party Libraries
 import six
 
-# Custom Libraries
 from splunk_appinspect.python_analyzer.ast_info_query import Any
 
 # Conditional Libraries
@@ -268,10 +265,10 @@ def get_name_list_from_attribute_chain(node):
 
 def get_name_from_attribute_chain(node):
     """
-        concatenate strings in attribute chain
+    concatenate strings in attribute chain
 
-        eg: a.b.c        return a.b.c
-            a.b.func()   return a.b.func
+    eg: a.b.c        return a.b.c
+        a.b.func()   return a.b.func
     """
     name_list = get_name_list_from_attribute_chain(node)
     # it is a legal name
@@ -280,7 +277,7 @@ def get_name_from_attribute_chain(node):
 
 def get_node_name_or_attr(node):
     """
-        get string value from ast.Name or ast.Attribute
+    get string value from ast.Name or ast.Attribute
     """
     if isinstance(node, ast.Name):
         return node.id
@@ -291,7 +288,7 @@ def get_node_name_or_attr(node):
     )
 
 
-def is_same_ast_tree(node1, node2, node1_extra=False):
+def is_same_ast_tree(node1, node2, node1_extra=False):  # noqa: C901
     r"""
         Here `SAME` means two AST trees have same tree structure, and when
         node type is Name, Str, Num, Attr, their value should be same
@@ -348,7 +345,7 @@ def is_same_ast_tree(node1, node2, node1_extra=False):
                     elif isinstance(current[0], ast.Str):
                         # use regex in string comparision, add ^ and $ to
                         # enforce complete match
-                        pattern = re.compile("^{}$".format(current[1].s))
+                        pattern = re.compile(f"^{current[1].s}$")
                         if not pattern.match(current[0].s):
                             return False
                     else:
