@@ -1,9 +1,6 @@
 # Copyright 2020 Splunk Inc. All rights reserved.
 """Splunk telemetry.conf abstraction module"""
-
-# Custom Libraries
-from . import configuration_file
-from . import splunk
+from . import configuration_file, splunk
 
 
 class TelemetryConfigurationFile(configuration_file.ConfigurationFile):
